Jupyter JS Widgets
==================

Interactive widgets for the Jupyter notebook.

This packages contains the implementation of the core Jupyter interactive
widgets.

The reference Python backend, `ipywidgets` is available
[here](https://github.com/jupyter-widgets/ipywidgets), with more examples.

Package Install
---------------

**Prerequisites**
- [node](http://nodejs.org/)

Run the following command **at the root of this repository**.

```bash
npm install --save @jupyter-widgets/controls
```
